@@ -31,6 +31,8 @@ def bin2text(binary_text):
 	if not " " in binary_text and len(binary_text)>8:
 		raise ValueError(noSpaceError.format("binary_text"))
 
+	binary_text = binary_text.strip()
+
 	#Converts the bin to text
 	plain_string = "".join([chr(int(x, 2)) for x in binary_text.split(" ")])
 	return plain_string 
@@ -42,6 +44,8 @@ def oct2text(oct_text):
 	if not " " in oct_text and len(oct_text)>3:
 		raise ValueError(noSpaceError.format("oct_text"))
 
+	oct_text = oct_text.strip()
+
 	#Converts the oct to text
 	plain_string = ''.join([chr(int(''.join(x), 8)) for x in oct_text.split(" ")])
 	return plain_string 	
@@ -52,6 +56,8 @@ def hex2text(hex_text):
 	if not " " in hex_text and len(hex_text)>2:
 		raise ValueError(noSpaceError.format("hex_text"))
 
+	hex_text = hex_text.strip()
+
 	#Converts the hex to text
 	plain_string = ''.join([chr(int(''.join(x), 16)) for x in hex_text.split(" ")])
 	return plain_string 	
@@ -62,6 +68,8 @@ def ascii2text(ascii_text):
 	if not " " in ascii_text and len(ascii_text)>3:
 		raise ValueError(noSpaceError.format("ascii_text"))
 
+	ascii_text = ascii_text.strip()
+
 	#Converts the ascii to plain text
 	plain_string = ''.join([chr(int(''.join(x))) for x in ascii_text.split(" ")])
 	return plain_string
@@ -89,6 +97,8 @@ def text2atbash(text):
 
 def text2railfence(text, key = 3): 
 
+	text = text.replace("\n", "")
+
 	rail = [['\n' for i in range(len(text))] 
 				  for j in range(key)] 
 	  
@@ -144,13 +154,13 @@ def caesar2text(encrypted_text,shift = 3):
 	return translated
 
 def caesarBruteforce(encrypted_text):  
-	posibilities = []
+	possibilities = []
 
 	for shift in range(26):
 		decoded = caesar2text(encrypted_text,shift)
-		posibilities.append(decoded)
+		possibilities.append(decoded)
 
-	return posibilities
+	return possibilities
 
 def atbash2text(encrypted_text):
 	translated = ""
@@ -169,6 +179,8 @@ def atbash2text(encrypted_text):
 
 def railfence2text(cipher, key = 3): 
 
+	cipher = cipher.replace("\n", "")
+
 	rail = [['\n' for i in range(len(cipher))]  
 				  for j in range(key)] 
 	  
@@ -227,7 +239,7 @@ def railfence2text(cipher, key = 3):
 #Misc 
 
 def reverse(text):
-	''' Reverses the text in the arguement '''
+	''' Reverses the text in the argument '''
 	return text[::-1]
 
 def capitalLettersCipher(ciphertext):
@@ -252,4 +264,6 @@ def firstLetterCipher(ciphertext):
 	Cipher Text: Horses evertime look positive
 	Decoded text: Help """  
 
+	ciphertext = ciphertext.strip()
+
 	return "".join([i[0] for i in ciphertext.split(" ")])
